@@ -1,12 +1,13 @@
 # coding=utf-8
 #
-# This file is part of Hypothesis (https://github.com/DRMacIver/hypothesis)
+# This file is part of Hypothesis, which may be found at
+# https://github.com/HypothesisWorks/hypothesis-python
 #
 # Most of this work is copyright (C) 2013-2015 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
-# https://github.com/DRMacIver/hypothesis/blob/master/CONTRIBUTING.rst for a
-# full list of people who may hold copyright, and consult the git log if you
-# need to determine who owns an individual contribution.
+# CONTRIBUTING.rst for a full list of people who may hold copyright, and
+# consult the git log if you need to determine who owns an individual
+# contribution.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
@@ -19,7 +20,8 @@ from __future__ import division, print_function, absolute_import
 import inspect
 
 from hypothesis._settings import settings, Verbosity
-from hypothesis.internal.compat import text_type, escape_unicode_characters
+from hypothesis.internal.compat import print_unicode, \
+    escape_unicode_characters
 from hypothesis.utils.dynamicvariables import DynamicVariable
 
 
@@ -29,9 +31,9 @@ def silent(value):
 
 def default(value):
     try:
-        print(value)
+        print_unicode(value)
     except UnicodeEncodeError:
-        print(escape_unicode_characters(value))
+        print_unicode(escape_unicode_characters(value))
 
 
 reporter = DynamicVariable(default)
@@ -52,7 +54,9 @@ def current_verbosity():
 def to_text(textish):
     if inspect.isfunction(textish):
         textish = textish()
-    return text_type(textish)
+    if isinstance(textish, bytes):
+        textish = textish.decode('utf-8')
+    return textish
 
 
 def verbose_report(text):
