@@ -1,12 +1,13 @@
 # coding=utf-8
 #
-# This file is part of Hypothesis (https://github.com/DRMacIver/hypothesis)
+# This file is part of Hypothesis, which may be found at
+# https://github.com/HypothesisWorks/hypothesis-python
 #
 # Most of this work is copyright (C) 2013-2015 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
-# https://github.com/DRMacIver/hypothesis/blob/master/CONTRIBUTING.rst for a
-# full list of people who may hold copyright, and consult the git log if you
-# need to determine who owns an individual contribution.
+# CONTRIBUTING.rst for a full list of people who may hold copyright, and
+# consult the git log if you need to determine who owns an individual
+# contribution.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
@@ -26,10 +27,12 @@ from hypothesis.internal.compat import ArgSpec, text_type, getargspec, \
     integer_types, float_to_decimal
 from hypothesis.internal.floats import is_negative, float_to_int, \
     int_to_float, count_between_floats
+from hypothesis.utils.conventions import not_set
 from hypothesis.internal.reflection import proxies
 from hypothesis.searchstrategy.reprwrapper import ReprWrapperStrategy
 
 __all__ = [
+    'nothing',
     'just', 'one_of',
     'none',
     'choices', 'streaming',
@@ -42,8 +45,7 @@ __all__ = [
     'builds',
     'randoms', 'random_module',
     'recursive', 'composite',
-    'shared',
-    'recursive', 'composite',
+    'shared', 'runner',
 ]
 
 _strategies = set()
@@ -106,6 +108,34 @@ def defines_strategy(strategy_definition):
     return accept
 
 
+class Nothing(SearchStrategy):
+    is_empty = True
+
+    def do_draw(self, data):
+        data.mark_invalid()
+
+    def __repr__(self):
+        return 'nothing()'
+
+    def map(self, f):
+        return self
+
+    def filter(self, f):
+        return self
+
+    def flatmap(self, f):
+        return self
+
+NOTHING = Nothing()
+
+
+@cacheable
+def nothing():
+    """This strategy never successfully draws a value and will always reject on
+    an attempt to draw."""
+    return NOTHING
+
+
 def just(value):
     """Return a strategy which only generates value.
 
@@ -126,17 +156,29 @@ def none():
     return just(None)
 
 
-def one_of(arg, *args):
+def one_of(*args):
     """Return a strategy which generates values from any of the argument
-    strategies."""
+    strategies.
+
+    This may be called with one iterable argument instead of multiple strategy
+    arguments. In which case one_of(x) and one_of(\*x) are equivalent.
+
+    """
+    if len(args) == 1 and not isinstance(args[0], SearchStrategy):
+        try:
+            args = tuple(args[0])
+        except TypeError:
+            pass
 
-    if not args:
-        check_strategy(arg)
-        return arg
-    from hypothesis.searchstrategy.strategies import OneOfStrategy
-    args = (arg,) + args
     for arg in args:
         check_strategy(arg)
+    args = [a for a in args if not a.is_empty]
+
+    if not args:
+        return nothing()
+    if len(args) == 1:
+        return args[0]
+    from hypothesis.searchstrategy.strategies import OneOfStrategy
     return OneOfStrategy(args)
 
 
@@ -332,6 +374,10 @@ def tuples(*args):
     """
     for arg in args:
         check_strategy(arg)
+
+    for arg in args:
+        if arg.is_empty:
+            return nothing()
     from hypothesis.searchstrategy.collections import TupleStrategy
     return TupleStrategy(args, tuple)
 
@@ -350,9 +396,7 @@ def sampled_from(elements):
         JustStrategy
     elements = tuple(iter(elements))
     if not elements:
-        raise InvalidArgument(
-            'sampled_from requires at least one value'
-        )
+        return nothing()
     if len(elements) == 1:
         return JustStrategy(elements[0])
     else:
@@ -391,7 +435,14 @@ def lists(
             )
         else:
             return builds(list)
-
+    check_strategy(elements)
+    if elements.is_empty:
+        if (min_size or 0) > 0:
+            raise InvalidArgument((
+                'Cannot create non-empty lists with elements drawn from '
+                'strategy %r because it has no values.') % (elements,))
+        else:
+            return builds(list)
     if unique:
         if unique_by is not None:
             raise InvalidArgument((
@@ -485,7 +536,10 @@ def fixed_dictionaries(mapping):
     from hypothesis.searchstrategy.collections import FixedKeysDictStrategy
     check_type(dict, mapping)
     for v in mapping.values():
-        check_type(SearchStrategy, v)
+        check_strategy(v)
+    for v in mapping.values():
+        if v.is_empty:
+            return nothing()
     return FixedKeysDictStrategy(mapping)
 
 
@@ -876,6 +930,33 @@ def uuids():
         ), 'uuids()')
 
 
+@defines_strategy
+def runner(default=not_set):
+    """A strategy for getting "the current test runner", whatever that may be.
+    The exact meaning depends on the entry point, but it will usually be the
+    associated 'self' value for it.
+
+    If there is no current test runner and a default is provided, return
+    that default. If no default is provided, raises InvalidArgument.
+
+    """
+    class RunnerStrategy(SearchStrategy):
+
+        def do_draw(self, data):
+            runner = getattr(data, 'hypothesis_runner', not_set)
+            if runner is not_set:
+                if default is not_set:
+                    raise InvalidArgument(
+                        'Cannot use runner() strategy with no '
+                        'associated runner or explicit default.'
+                    )
+                else:
+                    return default
+            else:
+                return runner
+    return RunnerStrategy()
+
+
 @cacheable
 def data():
     """This isn't really a normal strategy, but instead gives you an object
